summaryrefslogtreecommitdiff
path: root/usr.sbin/ppp/bundle.h
diff options
context:
space:
mode:
authorBrian Somers <brian@FreeBSD.org>1998-06-12 17:45:10 +0000
committerBrian Somers <brian@FreeBSD.org>1998-06-12 17:45:10 +0000
commitff0f9439b4c512a0c3318fa24b4f21f679399b1c (patch)
treeddadd012a3e6852633920b8ac41b2edf2fe20f0d /usr.sbin/ppp/bundle.h
parent7ec6ca7ce0689a447c54b5c198fcc74befcbd7b6 (diff)
downloadsrc-test2-ff0f9439b4c512a0c3318fa24b4f21f679399b1c.tar.gz
src-test2-ff0f9439b4c512a0c3318fa24b4f21f679399b1c.zip
Notes
Diffstat (limited to 'usr.sbin/ppp/bundle.h')
-rw-r--r--usr.sbin/ppp/bundle.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/usr.sbin/ppp/bundle.h b/usr.sbin/ppp/bundle.h
index d91237bdaabe..6a8042c261cf 100644
--- a/usr.sbin/ppp/bundle.h
+++ b/usr.sbin/ppp/bundle.h
@@ -23,7 +23,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: bundle.h,v 1.5 1998/05/29 18:33:08 brian Exp $
+ * $Id: bundle.h,v 1.6 1998/06/06 20:50:56 brian Exp $
*/
#define PHASE_DEAD 0 /* Link is dead */
@@ -70,7 +70,11 @@ struct bundle {
int routing_seq; /* The current routing sequence number */
u_int phase; /* Curent phase */
- int phys_type; /* Union of all physical::type's */
+
+ struct {
+ int all; /* Union of all physical::type's */
+ int open; /* Union of all open physical::type's */
+ } phys_type;
unsigned CleaningUp : 1; /* Going to exit.... */